@@ -1,5 +1,5 @@
 from .aerodynamics import *
 from .geometry import *
 from .performance import *
-from .casadi_helpers import *
+from aerosandbox.tools.casadi_tools import *
 from .library import *
\ No newline at end of file
